# Neural Network Visualizer

## What it is?

A module which creates a neural network with the given architecture(only Dense layers)

## Installation

### Before installation

Before installing the module, run the below command at your prompt to install the graphviz
```shell
$ sudo apt install graphviz
```

### Normal installation
```shell
$ sudo pip3 install neuralnet-visualize
```

### Development installation
```shell
$ git clone https://github.com/AnuragAnalog/nn_visualize.git
$ cd nn_visualize
```

### After installation

After installing the module, if you want to upgrade the module, run the below command.
```shell
sudo pip3 install neuralnet-visualize --upgrade
```

## How it looks?
![A demo](./My-Neural-Network.gv.png)

## Future Works

* Add Convolutional layers, Maxpooling, Flatten layers, LSTM's
* Specific colors for activation functions
* Specific colors for types of layers